@@ -7,6 +7,9 @@
  *
  * @author John Levon
  * @author Philippe Elie
+ *
+ * Modified by Maynard Johnson <maynardj@us.ibm.com>
+ * (C) Copyright IBM Corporation 2007
  */
 
 #include "profile.h"
@@ -15,6 +18,7 @@
 #include "op_bfd.h"
 #include "op_header.h"
 #include "populate.h"
+#include "populate_for_spu.h"
 
 #include "image_errors.h"
 
@@ -56,8 +60,11 @@ populate_for_image(string const & archive_path, profile_container & samples,
    inverted_profile const & ip, string_filter const & symbol_filter,
    bool * has_debug_info)
 {
-	bool ok = ip.error == image_ok;
+	if (is_spu_profile(ip))
+		return populate_for_spu_image(archive_path, samples, ip,
+					      symbol_filter, has_debug_info);
 
+	bool ok = ip.error == image_ok;
 	op_bfd abfd(archive_path, ip.image, symbol_filter, ok);
 	if (!ok && ip.error == image_ok)
 		ip.error = image_format_failure;
@@ -88,9 +95,8 @@ populate_for_image(string const & archive_path, profile_container & samples,
 		}
 	}
 
-	// we shouldn't check/warn if an archive is used
-	if (archive_path.empty() && found == true && ip.error == image_ok)
-		check_mtime(abfd.get_filename(), header);
+	if (found == true && ip.error == image_ok)
+		check_mtime(archive_path + abfd.get_filename(), header);
 
 	if (has_debug_info)
 		*has_debug_info = abfd.has_debug_info();
